<?php
/**
 * Enqueue functions
 * 
 * This template file contains the enqueue scripts and styles for the theme
 * also for deregistering scripts & styles.
 *
 * @package 	Rumput Hijau
 * @author		Satrya
 * @license		license.txt
 * @since 		Rumput Hijau 1.0.8
 *
 */
?>
<?php
add_action( 'admin_print_styles-appearance_page_theme_options', 'rumputhijau_admin_enqueue_script' );
add_action( 'wp_enqueue_scripts', 'rumputhijau_enqueue_scripts' );
add_action( 'wp_enqueue_scripts', 'rumputhijau_enqueue_styles' );
add_action( 'wp_print_styles', 'rumputhijau_deregister_styles', 100 );
add_action( 'wp_footer', 'rumputhijau_js_ie' );
add_action( 'comment_form_before', 'rumputhijau_enqueue_comment_reply_script' );

/**
 * Enqueue styles and scripts for the theme options page
 *
 * @since Rumput Hijau 1.0.8
 */
function rumputhijau_admin_enqueue_script( $hook_suffix ) {
	
	wp_enqueue_style( 'rumputhijau-options-style', get_template_directory_uri() . '/includes/options/style/admin.css', false, '1.0.0');
	wp_enqueue_style('thickbox');
	
	
	wp_register_script('rumputhijau_my-upload', get_template_directory_uri().'/includes/options/js/theme-options.js', array('jquery','media-upload','thickbox'));
	
	wp_enqueue_script('media-upload');
	wp_enqueue_script('thickbox');
	wp_enqueue_script('rumputhijau_my-upload');

}

/**
 * Enqueue styles
 *
 * @since Rumput Hijau 1.1.1
 */
function rumputhijau_enqueue_styles() {
	
	wp_enqueue_style( 'rumputhijau-style', get_stylesheet_uri(), '', '1.5', 'all' );
	
	wp_enqueue_style( 'rumputhijau-print', get_template_directory_uri() . '/css/print.css', '', '1.0.0', 'print' );
	
}

/**
 * Enqueue scripts
 *
 * @since Rumput Hijau 1.1.1
 */
function rumputhijau_enqueue_scripts() {
	global $post;
	
	wp_enqueue_script( 'jquery' );
	
	wp_enqueue_script( 'rumputhijau-modernizr', get_template_directory_uri() . '/js/vendor/modernizr-2.6.2.min.js', array('jquery'), '2.6.2' );
	
	wp_enqueue_script( 'rumputhijau-plugins', get_template_directory_uri() . '/js/plugins.js', array('jquery'), '20120615', true );
	
	wp_enqueue_script( 'rumputhijau-methods', get_template_directory_uri() . '/js/methods.js', array('jquery'), '20120615', true );
    
	if ( is_singular() && wp_attachment_is_image( $post->ID ) ) {
		wp_enqueue_script( 'keyboard-image-navigation', get_template_directory_uri() . '/js/vendor/keyboard-image-navigation.js', array( 'jquery' ), '20120615' );
	}
}

/**
 * Deregistering styles
 *
 * @since Rumput Hijau 1.1.1
 */
function rumputhijau_deregister_styles() {
	wp_deregister_style( 'wp-pagenavi' ); // deregistering default wp-pagenavi style
}

/**
 * JS library only for IE
 *
 * @since Rumput Hijau 1.1.1
 */
function rumputhijau_js_ie() { ?>
	<!--[if (gte IE 6)&(lte IE 8)]>
		<script src="<?php echo get_template_directory_uri(); ?>/js/vendor/selectivizr-min.js"></script>
	<![endif]-->
	
<?php 
}

/**
 * Comment reply js
 *
 * @since Rumput Hijau 1.1.8
 */
function rumputhijau_enqueue_comment_reply_script() {
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
?>