<?php
/**
 * Implements Rumput Hijau theme options into Theme Customizer
 *
 * @param 		$wp_customize Theme Customizer object
 * @return 		void
 * @credit		twentyeleven
 *
 * @package 	Rumput Hijau
 * @author		Satrya
 * @license		license.txt
 * @since 		Rumput Hijau 1.1.5
 *
 */
?>
<?php

function rumputhijau_customize_register( $wp_customize ) {
	
	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
	
	$options = rumputhijau_get_theme_options();
	$defaults = rumputhijau_get_default_theme_options();
	
	
	// Default Font
	$wp_customize->add_section( 'rumputhijau_font_stack', array(
		'title'    => __( 'Rumput Hijau Fonts', 'rumputhijau' ),
		'priority' => 50,
	) );

	$wp_customize->add_setting( 'rumputhijau_theme_options[font_stack]', array(
		'type'              => 'option',
		'default'           => $defaults['font_stack'],
		'capability' 		=> 'edit_theme_options',
	) );

	$fonts = rumputhijau_font_stack();
	$choices = array();
	foreach ( $fonts as $font ) {
		$choices[$font['value']] = $font['label'];
	}

	$wp_customize->add_control( 'rumputhijau_theme_options[font_stack]', array(
		'section'    => 'rumputhijau_font_stack',
		'type'       => 'select',
		'choices'    => $choices,
	) );
	
	
	// Default Layout
	$wp_customize->add_section( 'rumputhijau_layouts', array(
		'title'    => __( 'Rumput Hijau Layouts', 'rumputhijau' ),
		'priority' => 50,
	) );

	$wp_customize->add_setting( 'rumputhijau_theme_options[theme_layout]', array(
		'type'              => 'option',
		'default'           => $defaults['theme_layout'],
		'sanitize_callback' => 'sanitize_key',
	) );

	$layouts = rumputhijau_layouts();
	$choices = array();
	foreach ( $layouts as $layout ) {
		$choices[$layout['value']] = $layout['label'];
	}

	$wp_customize->add_control( 'rumputhijau_theme_options[theme_layout]', array(
		'section'    => 'rumputhijau_layouts',
		'type'       => 'radio',
		'choices'    => $choices,
	) );
	
}
add_action( 'customize_register', 'rumputhijau_customize_register' );

/**
 * Bind JS handlers to make Theme Customizer preview reload changes asynchronously.
 * Used with blogname and blogdescription.
 *
 * @since Rumput Hijau 1.1.5
 */
function rumputhijau_customize_preview_js() {
	wp_enqueue_script( 'twentyeleven-customizer', get_template_directory_uri() . '/includes/options/js/theme-customizer.js', array( 'customize-preview' ), '20120523', true );
}
add_action( 'customize_preview_init', 'rumputhijau_customize_preview_js' );
?>