<?php
/**
 * Define Theme setup
 * 
 * This file defines the setup functions for the Rumput Hijau Theme.
 *
 * @package 	Rumput Hijau
 * @author		Satrya
 * @license		license.txt
 * @since 		Rumput Hijau 1.1.3
 *
 */
?>
<?php
add_action( 'after_setup_theme', 'rumputhijau_setup' );
if ( ! function_exists( 'rumputhijau_setup' ) ):

function rumputhijau_setup() {

	/**
	 * Set the content width based on the theme's design and stylesheet.
	 */
	global $content_width;
	if ( ! isset( $content_width ) )
	$content_width = 700;
	
	/* Make Rumput Hijau available for translation.
	 * Translations can be added to the /languages/ directory.
	 * If you're building a theme based on Rumput Hijau, use a find and replace
	 * to change 'rumputhijau' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'rumputhijau', get_template_directory() . '/languages' );
	
	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style( 'css/editor-style.css' );
	
	// Add default posts and comments RSS feed links to <head>.
	add_theme_support( 'automatic-feed-links' );
	
	// Add support for custom backgrounds
	add_theme_support( 'custom-background' );
		
	// Add support post-formats
	add_theme_support( 'post-formats', array( 'aside', 'gallery', 'link', 'video', 'image', 'quote' ) );
	
	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Primary Menu', 'rumputhijau' ) );
	
	// This theme uses Featured Image (also known as post thumbnails)
	add_theme_support( 'post-thumbnails' );
	// Add custom image sizes
	add_image_size( '150px' , 150, 100, true ); // 150px thumbnail
	
	// Load the theme options & the theme options functions
	require_once get_template_directory() . '/includes/options/options.php';
	require_once get_template_directory() . '/includes/options/options-functions.php';
	require_once get_template_directory() . '/includes/options/options-customizer.php';
	
} 
endif; // end rumputhijau_setup()

/**
 * Custom Header
 *
 * @package Rumput hijau
 * @since Rumput Hijau 1.5
 */
add_action( 'after_setup_theme', 'rumputhijau_custom_header_setup' );
function rumputhijau_custom_header_setup() {
	$args = array(
		'default-text-color'     => '',
		'default-image'          => get_template_directory_uri() . '/img/headers/default-header.jpg',
		'height'                 => 200,
		'header-text'            => false,
		'width'                  => 950,
		'flex-height'            => true,
		'flex-width'             => true,
		'random-default'         => false,

		// Callbacks for styling the header and the admin preview.
		'admin-head-callback'    => 'rumputhijau_admin_header_style',

	);

	add_theme_support( 'custom-header', $args );

	// Default custom headers packaged with the theme. %s is a placeholder for the theme template directory URI.
	register_default_headers( array(
		'default' => array(
			'url' => '%s/img/headers/default-header.jpg',
			'thumbnail_url' => '%s/img/headers/default-header-thumb.jpg',
			/* translators: header image description */
			'description' => __( 'Default', 'rumputhijau' )
		),
		'rumput-hijau-1' => array(
			'url' => '%s/img/headers/rumput-hijau-1.jpg',
			'thumbnail_url' => '%s/img/headers/rumput-hijau-1-thumb.jpg',
			/* translators: header image description */
			'description' => __( 'Rumput Hijau 1', 'rumputhijau' )
		),
		'rumput-hijau-2' => array(
			'url' => '%s/img/headers/rumput-hijau-2.jpg',
			'thumbnail_url' => '%s/img/headers/rumput-hijau-2-thumb.jpg',
			/* translators: header image description */
			'description' => __( 'Rumput Hijau 2', 'rumputhijau' )
		),
		'rumput-hijau-3' => array(
			'url' => '%s/img/headers/rumput-hijau-3.jpg',
			'thumbnail_url' => '%s/img/headers/rumput-hijau-3-thumb.jpg',
			/* translators: header image description */
			'description' => __( 'Rumput Hijau 3', 'rumputhijau' )
		),
	) );

}

/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 *
 * @package Rumput hijau
 * @since Rumput Hijau 1.1.3
 */
function rumputhijau_admin_header_style() { ?>
	<style type="text/css">
	#headimg {
		background:#fff url(<?php header_image() ?>) no-repeat center;  
		height: <?php echo HEADER_IMAGE_HEIGHT; ?>px;
		width: <?php echo HEADER_IMAGE_WIDTH; ?>px;
	}
	</style>
	<?php
}