<?php
/**
 * Rumput Hijau custom template tags
 * 
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package 	Rumput Hijau
 * @author		Satrya
 * @license		license.txt
 * @since 		Rumput Hijau 1.1.0
 *
 */
?>
<?php
/**
 * Top Navigation
 * You can change or remove this functions in a child theme
 * by removing the action first, then add your own custom function
 *
 * @since Rumput Hijau 1.1.0
 */
add_action('rumputhijau_before', 'rumputhijau_top_navigation');
function rumputhijau_top_navigation() {
	?>
	
	<nav role="navigation" id="primary-nav" class="site-navigation main-navigation clearfix">
		<div class="inside-primary-nav">
		
			<?php wp_nav_menu(array(
				    'container'      => '',
					'menu_class' 	 => 'nav',
					'theme_location' => 'primary')
					); 
				?>

			<?php get_search_form(); ?><!-- get the search form, defined in searchform.php -->
			
		</div><!-- end .inside-primary-nav -->
	</nav><!-- end #primary-nav -->
	
<?php 
}
 
/**
 * Header content
 *
 * If you want to remove or change this function in a child theme
 * add this code to the child theme functions.php
 * function unhook_rumputhijau_header_content() {
		remove_action('rumputhijau_header', 'rumputhijau_header_content');
   }
   add_action('init','unhook_rumputhijau_header_content');
 *
 *
 * @since Rumput Hijau 1.1.0
 */
add_action('rumputhijau_header', 'rumputhijau_header_content');
function rumputhijau_header_content() {
	$options = rumputhijau_get_theme_options();
	?>
	
	<div class="site-branding clearfix">
		
		<?php $logo = isset($options['logo'])? $options['logo']: '';
		if ($logo == "") {
		
			// Do not show <h1> except on home page, SEO reason
			if(!is_home() || !is_front_page()) { ?>
				<span class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo('name'); ?></a></span>
				<div class="site-description last"><?php bloginfo('description'); ?></div>
			<?php } else { 
			// Only on home page display the <h1> tag, SEO reason
			?>
				<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo('name'); ?></a></h1>
				<div class="site-description last"><?php bloginfo('description'); ?></div>
			<?php }
			
			} else {
				if (is_home() || is_front_page()) { ?>
					<h1 class="logo-image"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php echo esc_url( $logo ); ?>" alt="<?php bloginfo('name'); ?>" title="<?php bloginfo('name'); ?>" /><span><?php bloginfo('name'); ?></span></a></h1>
				<?php } else {  ?>
					<div class="logo-image"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php echo esc_url( $logo ); ?>" alt="<?php bloginfo('name'); ?>" title="<?php bloginfo('name'); ?>" /><span><?php bloginfo('name'); ?></span></a></div>
			<?php } } ?>
		
	</div><!-- end .site-branding -->
	
	<?php rumputhijau_custom_header(); // call the custom header feature ?>

<?php 
}

/**
 * Custom header feature
 * Just create your own rumputhijau_custom_header to override in a child theme 
 * With your own custom header function or maybe you can create a custom slider
 * 
 *
 * @since Rumput Hijau 1.1.0
 */
if ( ! function_exists( 'rumputhijau_custom_header' ) ) :

function rumputhijau_custom_header() {
	$header_image = get_header_image(); 
	if ( ! empty( $header_image ) ) { ?>
	
	<div class="header-img">
		<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home">
			<img src="<?php header_image(); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>">
		</a>
	</div><!-- .header-img -->
	
	<?php } // if ( ! empty( $header_image ) )
}
endif;

/**
 * Plug-and-play support for the Yoast Breadcrumbs plugins if exist.
 * If not, it will echo the custom breadcrumbs
 *
 * @since Rumput Hijau 1.1.0
 */
add_action('rumputhijau_header_after', 'rumputhijau_breadcrumbs_function');
function rumputhijau_breadcrumbs_function() {

	if ( function_exists('yoast_breadcrumb') ) { yoast_breadcrumb('<div id="breadcrumbs">','</div>');
	} else {
		echo rumputhijau_breadcrumbs(); // defined in includes/extensions.php
	}
	
}

if ( ! function_exists( 'rumputhijau_content_nav' ) ):
/**
 * Display navigation to next/previous pages when applicable
 *
 * @since Rumput Hijau 1.1.5
 */
function rumputhijau_content_nav( $nav_id ) {
	global $wp_query;

	$nav_class = 'site-navigation paging-navigation clearfix';
	if ( is_single() )
		$nav_class = 'site-navigation post-navigation clearfix';

	?>
	<nav role="navigation" id="<?php echo $nav_id; ?>" class="<?php echo $nav_class; ?>">
		<h5 class="assistive-text"><?php _e( 'Post navigation', 'rumputhijau' ); ?></h5>

	<?php if ( is_single() ) : // navigation links for single posts ?>

		<?php previous_post_link( '<div class="nav-previous">%link</div>', '<span class="meta-nav">' . _x( '&larr;', 'Previous post link', 'rumputhijau' ) . '</span> %title' ); ?>
		<?php next_post_link( '<div class="nav-next">%link</div>', '%title <span class="meta-nav">' . _x( '&rarr;', 'Next post link', 'rumputhijau' ) . '</span>' ); ?>

	<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : // navigation links for home, archive, and search pages ?>
		
		<?php if( function_exists('wp_pagenavi') ) : wp_pagenavi(); else : // use wp-pagenavi if exist ?>
			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'rumputhijau' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'rumputhijau' ) ); ?></div>
			<?php endif; ?>
		<?php endif; ?>

	<?php endif; ?>

	</nav><!-- #<?php echo $nav_id; ?> -->
	<?php
}
endif; // rumputhijau_content_nav
 
if ( ! function_exists( 'rumputhijau_entry_meta' ) ) :
/**
 * Prints HTML with meta information for the tags & categories.
 * Create your own rumputhijau_entry_meta to override in a child theme
 *
 * @since Rumput Hijau 1.1.0
 */
function rumputhijau_entry_meta() {
	$tags_list = get_the_tag_list( '', ', ' );
		printf( __( '<span class="%1$s">%2$s</span>', 'rumputhijau' ), 'entry-utility-prep entry-utility-prep-tag-links tag', $tags_list );

	$categories_list = get_the_category_list(', ');
		printf( __( '<span class="%1$s category">%2$s</span>', 'rumputhijau' ), 'entry-utility-prep entry-utility-prep-cat-links cat', $categories_list );
	
	edit_post_link( __( 'Edit', 'rumputhijau' ), '<span class="edit-link">', '</span>' );
}
endif;

if ( ! function_exists( 'rumputhijau_content_left' ) ):
/**
 * Prints HTML with meta information for the current post-date/time, author, comments,
 * custom social button and permalink.
 * Create your own rumputhijau_content_left to override in a child theme
 *
 * @since Rumput Hijau 1.0.8
 */
function rumputhijau_content_left() {
	global $post;
	?>
	<div class="content-left">
	
		<?php
		printf(
			__('<span class="published">%1$s</span><span class="author vcard"><a class="url fn n" href="%2$s" title="%3$s" rel="author">%4$s</a></span><span class="entry-permalink"><a href="%5$s" title="%6$s" rel="bookmark">Permalink</a></span>','rumputhijau'),
				esc_html( get_the_date() ),
				esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
				esc_attr( sprintf( __( 'View all posts by %s', 'rumputhijau' ), get_the_author() ) ),
				get_the_author(),
				esc_url( get_permalink() ),
				esc_attr( sprintf( __( 'Permalink to %s', 'rumputhijau' ), the_title_attribute( 'echo=0' ) ) )
		);
	?>
		<span class="entry-comment">
			<?php if ( comments_open() ) :
				comments_popup_link( __( 'Leave a comment', 'rumputhijau' ), __( '1 Comment', 'rumputhijau' ), __( '% Comments', 'rumputhijau' ) ); ?>
			<?php endif; ?>
		</span>
	
	</div><!-- end .content-left -->
	
<?php
}
endif;

if ( ! function_exists( 'rumputhijau_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since Rumput Hijau 1.1.5
 */
function rumputhijau_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="pingback">
		<p><?php _e( 'Pingback:', 'rumputhijau' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(Edit)', 'rumputhijau' ), ' ' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<footer>
				<div class="comment-author vcard">
					<?php echo get_avatar( $comment, 40 ); ?>
					<?php printf( __( '%s <span class="says">says:</span>', 'rumputhijau' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
				</div><!-- .comment-author .vcard -->
				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em><?php _e( 'Your comment is awaiting moderation.', 'rumputhijau' ); ?></em>
					<br />
				<?php endif; ?>

				<div class="comment-meta commentmetadata">
					<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>"><time pubdate datetime="<?php comment_time( 'c' ); ?>">
					<?php
						/* translators: 1: date, 2: time */
						printf( __( '%1$s at %2$s', 'rumputhijau' ), get_comment_date(), get_comment_time() ); ?>
					</time></a>
					<?php edit_comment_link( __( '(Edit)', 'rumputhijau' ), ' ' );
					?>
				</div><!-- .comment-meta .commentmetadata -->
			</footer>

			<div class="comment-content"><?php comment_text(); ?></div>

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</article><!-- #comment-## -->

	<?php
			break;
	endswitch;
}
endif; // ends check for rumputhijau_comment()

if ( ! function_exists( 'rumputhijau_comment_nav' ) ):
/**
 * Display comment navigation when applicable
 * Create your own rumputhijau_comment_nav to override in a child theme
 * 
 *
 * @since Rumput Hijau 1.1.0
 */
function rumputhijau_comment_nav() {
	if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through ?>
		<div class="comments-navigation clearfix">
			<div class="alignleft"><?php previous_comments_link( __( '&larr; Older Comments', 'rumputhijau' ) ); ?></div>
			<div class="alignright"><?php next_comments_link( __( 'Newer Comments &rarr;', 'rumputhijau' ) ); ?></div>
		</div> 
	<?php endif; // check for comment navigation
}

endif;